# CLI Usage

Most of the methods in `cylindra` can only be called from the GUI or in python scripts,
as any operations can be written in a python script and run by `python file-name.py`.

```bash
cylindra -h
```

``` title="Output:"
╭────────────────────────────────────────────────────╮
│ cylindra options commands arguments                │
╰────────────────────────────────────────────────────╯

options
    -v, --version   Show version.
    -h, --help      Show this message and exit.

commands
    open     Open a project or an image.
    preview  View a project, image etc.
    find     Find cylindra projects.
    run      Run a script.
    config   Edit/view the configuration.
    average  Average images.
    new      Create a new project.
    add      Add splines by coordinates.

```
